@@ -12,6 +12,7 @@ import java.util.List;
 import java.util.Map;
 import org.assertj.core.api.Assertions;
 import org.assertj.core.api.SoftAssertions;
+import org.testng.CommandLineArgs;
 import org.testng.ITestNGListener;
 import org.testng.TestNG;
 import org.testng.annotations.DataProvider;
@@ -63,6 +64,14 @@ public class ListenersTest extends SimpleBaseTest {
         "test.listeners.issue2638.TestClassBSample.testMethod"
       };
 
+  @Test(description = "GITHUB-3117")
+  public void ensureOrderingForExecutionListenersViaMaven() {
+    Ensure.orderingViaMap(
+        ExecutionListenerHolder.LOGS,
+        ExecutionListenerHolder.ALL,
+        ExecutionListenerHolder.EXPECTED_LOGS);
+  }
+
   @Test(description = "GITHUB-2916")
   public void ensureOrderingForExecutionListenersViaApi() {
     Ensure.orderingViaApi(
@@ -71,6 +80,14 @@ public class ListenersTest extends SimpleBaseTest {
         ExecutionListenerHolder.EXPECTED_LOGS);
   }
 
+  @Test(description = "GITHUB-3117")
+  public void ensureOrderingForAlterSuiteListenersViaMaven() {
+    Ensure.orderingViaMap(
+        AlterSuiteListenerHolder.LOGS,
+        AlterSuiteListenerHolder.ALL,
+        AlterSuiteListenerHolder.EXPECTED_LOGS);
+  }
+
   @Test(description = "GITHUB-2916")
   public void ensureOrderingForAlterSuiteListenersViaApi() {
     Ensure.orderingViaApi(
@@ -85,6 +102,12 @@ public class ListenersTest extends SimpleBaseTest {
         SuiteListenerHolder.LOGS, SuiteListenerHolder.ALL, SuiteListenerHolder.EXPECTED_LOGS);
   }
 
+  @Test(description = "GITHUB-3117")
+  public void ensureOrderingForSuiteListenersViaMaven() {
+    Ensure.orderingViaMap(
+        SuiteListenerHolder.LOGS, SuiteListenerHolder.ALL, SuiteListenerHolder.EXPECTED_LOGS);
+  }
+
   @Test(description = "GITHUB-2916")
   public void ensureOrderingForTestListenersViaApi() {
     Ensure.orderingViaApi(
@@ -94,6 +117,15 @@ public class ListenersTest extends SimpleBaseTest {
         TestListenerHolder.EXPECTED_LOGS);
   }
 
+  @Test(description = "GITHUB-3117")
+  public void ensureOrderingForTestListenersViaMaven() {
+    Ensure.orderingViaMap(
+        ElaborateSampleTestCase.class,
+        TestListenerHolder.LOGS,
+        TestListenerHolder.ALL,
+        TestListenerHolder.EXPECTED_LOGS);
+  }
+
   @Test(description = "GITHUB-2916")
   public void ensureOrderingForInvokedListenersViaApi() {
     Ensure.orderingViaApi(
@@ -102,6 +134,14 @@ public class ListenersTest extends SimpleBaseTest {
         InvokedMethodListenerHolder.EXPECTED_LOGS);
   }
 
+  @Test(description = "GITHUB-3117")
+  public void ensureOrderingForInvokedListenersViaMaven() {
+    Ensure.orderingViaMap(
+        InvokedMethodListenerHolder.LOGS,
+        InvokedMethodListenerHolder.ALL,
+        InvokedMethodListenerHolder.EXPECTED_LOGS);
+  }
+
   @Test(description = "GITHUB-2916")
   public void ensureOrderingForConfigurationListenersViaApi() {
     Ensure.orderingViaApi(
@@ -111,12 +151,27 @@ public class ListenersTest extends SimpleBaseTest {
         ConfigurationListenerHolder.EXPECTED_LOGS);
   }
 
+  @Test(description = "GITHUB-3117")
+  public void ensureOrderingForConfigurationListenersViaMaven() {
+    Ensure.orderingViaMap(
+        SimpleConfigTestCase.class,
+        ConfigurationListenerHolder.LOGS,
+        ConfigurationListenerHolder.ALL,
+        ConfigurationListenerHolder.EXPECTED_LOGS);
+  }
+
   @Test(description = "GITHUB-2916")
   public void ensureOrderingForClassListenersViaApi() {
     Ensure.orderingViaApi(
         ClassListenerHolder.LOGS, ClassListenerHolder.ALL, ClassListenerHolder.EXPECTED_LOGS);
   }
 
+  @Test(description = "GITHUB-3117")
+  public void ensureOrderingForClassListenersViaMaven() {
+    Ensure.orderingViaMap(
+        ClassListenerHolder.LOGS, ClassListenerHolder.ALL, ClassListenerHolder.EXPECTED_LOGS);
+  }
+
   @Test(description = "GITHUB-2916")
   public void ensureOrderingForDataProviderListenersViaApi() {
     Ensure.orderingViaApi(
@@ -126,6 +181,15 @@ public class ListenersTest extends SimpleBaseTest {
         DataProviderListenerHolder.EXPECTED_LOGS);
   }
 
+  @Test(description = "GITHUB-3117")
+  public void ensureOrderingForDataProviderListenersViaMaven() {
+    Ensure.orderingViaMap(
+        DataProviderSampleTestCase.class,
+        DataProviderListenerHolder.LOGS,
+        DataProviderListenerHolder.ALL,
+        DataProviderListenerHolder.EXPECTED_LOGS);
+  }
+
   @Test(description = "GITHUB-2916")
   public void ensureOrderingForDataProviderInterceptorsViaApi() {
     Ensure.orderingViaApi(
@@ -135,6 +199,15 @@ public class ListenersTest extends SimpleBaseTest {
         DataProviderInterceptorHolder.EXPECTED_LOGS);
   }
 
+  @Test(description = "GITHUB-3117")
+  public void ensureOrderingForDataProviderInterceptorsViaMaven() {
+    Ensure.orderingViaMap(
+        DataProviderSampleTestCase.class,
+        DataProviderListenerHolder.LOGS,
+        DataProviderListenerHolder.ALL,
+        DataProviderListenerHolder.EXPECTED_LOGS);
+  }
+
   @Test(description = "GITHUB-2916")
   public void ensureOrderingForExecutionVisualisersViaApi() {
     Ensure.orderingViaApi(
@@ -143,6 +216,14 @@ public class ListenersTest extends SimpleBaseTest {
         ExecutionVisualiserHolder.EXPECTED_LOGS);
   }
 
+  @Test(description = "GITHUB-3117")
+  public void ensureOrderingForExecutionVisualisersViaMaven() {
+    Ensure.orderingViaMap(
+        ExecutionVisualiserHolder.LOGS,
+        ExecutionVisualiserHolder.ALL,
+        ExecutionVisualiserHolder.EXPECTED_LOGS);
+  }
+
   @Test(description = "GITHUB-2916")
   public void ensureOrderingForMethodInterceptorsViaApi() {
     Ensure.orderingViaApi(
@@ -151,6 +232,14 @@ public class ListenersTest extends SimpleBaseTest {
         MethodInterceptorHolder.EXPECTED_LOGS);
   }
 
+  @Test(description = "GITHUB-3117")
+  public void ensureOrderingForMethodInterceptorsViaMaven() {
+    Ensure.orderingViaMap(
+        MethodInterceptorHolder.LOGS,
+        MethodInterceptorHolder.ALL,
+        MethodInterceptorHolder.EXPECTED_LOGS);
+  }
+
   @Test(description = "GITHUB-2916")
   public void ensureOrderingForExecutionListenersViaXmlTag() {
     Ensure.orderingViaXmlTag(
@@ -809,5 +898,25 @@ public class ListenersTest extends SimpleBaseTest {
       testng.run();
       assertThat(logs).containsExactly(expected);
     }
+
+    static void orderingViaMap(
+        List<String> logs, List<ITestNGListener> listeners, String[] expected) {
+      orderingViaMap(NormalSampleTestCase.class, logs, listeners, expected);
+    }
+
+    static void orderingViaMap(
+        Class<?> clazz, List<String> logs, List<ITestNGListener> listeners, String[] expected) {
+      logs.clear();
+      TestNG testng = create(clazz);
+      listeners.forEach(testng::addListener);
+      testng.setUseDefaultListeners(false);
+      Map<String, String> map =
+          Map.of(
+              CommandLineArgs.LISTENER_COMPARATOR,
+              AnnotationBackedListenerComparator.class.getName());
+      testng.configure(map);
+      testng.run();
+      assertThat(logs).containsExactly(expected);
+    }
   }
 }
